@@ -1,4 +1,4 @@
-from .strategy import Strategy
+from .strategy import Strategy, EvoState, EvoParams
 from .strategies import (
     SimpleGA,
     SimpleES,
@@ -9,7 +9,6 @@ from .strategies import (
     PGPE,
     PBT,
     PersistentES,
-    xNES,
     ARS,
     Sep_CMA_ES,
     BIPOP_CMA_ES,
@@ -21,6 +20,16 @@ from .strategies import (
     RmES,
     GLD,
     SimAnneal,
+    SNES,
+    xNES,
+    ESMC,
+    DES,
+    SAMR_GA,
+    GESMR_GA,
+    GuidedES,
+    ASEBO,
+    CR_FM_NES,
+    MR15_GA,
 )
 from .utils import FitnessShaper, ParameterReshaper, ESLog
 from .networks import NetworkMapper
@@ -37,7 +46,6 @@ Strategies = {
     "PGPE": PGPE,
     "PBT": PBT,
     "PersistentES": PersistentES,
-    "xNES": xNES,
     "ARS": ARS,
     "Sep_CMA_ES": Sep_CMA_ES,
     "BIPOP_CMA_ES": BIPOP_CMA_ES,
@@ -49,9 +57,27 @@ Strategies = {
     "RmES": RmES,
     "GLD": GLD,
     "SimAnneal": SimAnneal,
+    "SNES": SNES,
+    "xNES": xNES,
+    "ESMC": ESMC,
+    "DES": DES,
+    "SAMR_GA": SAMR_GA,
+    "GESMR_GA": GESMR_GA,
+    "GuidedES": GuidedES,
+    "ASEBO": ASEBO,
+    "CR_FM_NES": CR_FM_NES,
+    "MR15_GA": MR15_GA,
 }
 
 __all__ = [
+    "Strategies",
+    "EvoState",
+    "EvoParams",
+    "FitnessShaper",
+    "ParameterReshaper",
+    "ESLog",
+    "NetworkMapper",
+    "ProblemMapper",
     "Strategy",
     "SimpleGA",
     "SimpleES",
@@ -62,7 +88,6 @@ __all__ = [
     "PGPE",
     "PBT",
     "PersistentES",
-    "xNES",
     "ARS",
     "Sep_CMA_ES",
     "BIPOP_CMA_ES",
@@ -74,10 +99,14 @@ __all__ = [
     "RmES",
     "GLD",
     "SimAnneal",
-    "Strategies",
-    "FitnessShaper",
-    "ParameterReshaper",
-    "ESLog",
-    "NetworkMapper",
-    "ProblemMapper",
+    "SNES",
+    "xNES",
+    "ESMC",
+    "DES",
+    "SAMR_GA",
+    "GESMR_GA",
+    "GuidedES",
+    "ASEBO",
+    "CR_FM_NES",
+    "MR15_GA",
 ]
