@@ -1,9 +1,9 @@
 import jax
 import jax.numpy as jnp
 import chex
-from typing import Tuple
+from typing import Tuple, Optional, Union
 from ..strategy import Strategy
-from ..utils import GradientOptimizer, OptState, OptParams
+from ..utils import GradientOptimizer, OptState, OptParams, exp_decay
 from flax import struct
 
 
@@ -34,28 +34,54 @@ class EvoParams:
 class PGPE(Strategy):
     def __init__(
         self,
-        num_dims: int,
         popsize: int,
-        elite_ratio: float = 0.1,
-        opt_name: str = "sgd",
+        num_dims: Optional[int] = None,
+        pholder_params: Optional[Union[chex.ArrayTree, chex.Array]] = None,
+        elite_ratio: float = 1.0,
+        opt_name: str = "adam",
+        lrate_init: float = 0.05,
+        lrate_decay: float = 1.0,
+        lrate_limit: float = 0.001,
+        sigma_init: float = 0.03,
+        sigma_decay: float = 1.0,
+        sigma_limit: float = 0.01,
+        **fitness_kwargs: Union[bool, int, float]
     ):
         """PGPE (e.g. Sehnke et al., 2010)
         Reference: https://tinyurl.com/2p8bn956
         Inspired by: https://github.com/hardmaru/estool/blob/master/es.py"""
-        super().__init__(num_dims, popsize)
+        super().__init__(popsize, num_dims, pholder_params, **fitness_kwargs)
         assert 0 <= elite_ratio <= 1
         self.elite_ratio = elite_ratio
-        self.elite_popsize = int(self.popsize / 2 * self.elite_ratio)
+        self.elite_popsize = max(1, int(self.popsize / 2 * self.elite_ratio))
 
         assert not self.popsize & 1, "Population size must be even"
-        assert opt_name in ["sgd", "adam", "rmsprop", "clipup"]
+        assert opt_name in ["sgd", "adam", "rmsprop", "clipup", "adan"]
         self.optimizer = GradientOptimizer[opt_name](self.num_dims)
         self.strategy_name = "PGPE"
 
+        # Set core kwargs es_params (lrate/sigma schedules)
+        self.lrate_init = lrate_init
+        self.lrate_decay = lrate_decay
+        self.lrate_limit = lrate_limit
+        self.sigma_init = sigma_init
+        self.sigma_decay = sigma_decay
+        self.sigma_limit = sigma_limit
+
     @property
     def params_strategy(self) -> EvoParams:
         """Return default parameters of evolution strategy."""
-        return EvoParams(opt_params=self.optimizer.default_params)
+        opt_params = self.optimizer.default_params.replace(
+            lrate_init=self.lrate_init,
+            lrate_decay=self.lrate_decay,
+            lrate_limit=self.lrate_limit,
+        )
+        return EvoParams(
+            opt_params=opt_params,
+            sigma_init=self.sigma_init,
+            sigma_decay=self.sigma_decay,
+            sigma_limit=self.sigma_limit,
+        )
 
     def initialize_strategy(
         self, rng: chex.PRNGKey, params: EvoParams
@@ -85,7 +111,7 @@ class PGPE(Strategy):
             (int(self.popsize / 2), self.num_dims),
         )
         z = jnp.concatenate([z_plus, -1.0 * z_plus])
-        x = state.mean + z * state.sigma.reshape(1, self.num_dims)
+        x = state.mean + state.sigma * z
         return x, state
 
     def tell_strategy(
@@ -98,9 +124,9 @@ class PGPE(Strategy):
         """Update both mean and dim.-wise isotropic Gaussian scale."""
         # Reconstruct noise from last mean/std estimates
         noise = (x - state.mean) / state.sigma
-        noise_1 = noise[: int(self.popsize / 2)]
-        fit_1 = fitness[: int(self.popsize / 2)]
-        fit_2 = fitness[int(self.popsize / 2) :]
+        noise_1 = noise[::2]
+        fit_1 = fitness[::2]
+        fit_2 = fitness[1::2]
         elite_idx = jnp.minimum(fit_1, fit_2).argsort()[: self.elite_popsize]
 
         fitness_elite = jnp.concatenate([fit_1[elite_idx], fit_2[elite_idx]])
@@ -120,18 +146,18 @@ class PGPE(Strategy):
             - (state.sigma * state.sigma).reshape(1, self.num_dims)
         ) / state.sigma.reshape(1, self.num_dims)
         rS = (fit_1 + fit_2) / 2.0 - jnp.mean(fitness_elite)
-        delta_sigma = (jnp.dot(rS, S)) / self.elite_popsize
-        change_sigma = params.sigma_lrate * delta_sigma
-        change_sigma = jnp.minimum(
-            change_sigma, params.sigma_max_change * state.sigma
-        )
-        change_sigma = jnp.maximum(
-            change_sigma, -params.sigma_max_change * state.sigma
-        )
+        delta_sigma = jnp.dot(rS, S) / (self.elite_popsize / 2)
+
+        allowed_delta = jnp.abs(state.sigma) * params.sigma_max_change
+        min_allowed = state.sigma - allowed_delta
+        max_allowed = state.sigma + allowed_delta
 
         # adjust sigma according to the adaptive sigma calculation
         # for stability, don't let sigma move more than 20% of orig value
-        sigma = state.sigma - change_sigma
-        sigma = sigma * params.sigma_decay
-        sigma = jnp.maximum(sigma, params.sigma_limit)
+        sigma = jnp.clip(
+            state.sigma - params.sigma_lrate * delta_sigma,
+            min_allowed,
+            max_allowed,
+        )
+        sigma = exp_decay(state.sigma, params.sigma_decay, params.sigma_limit)
         return state.replace(mean=mean, sigma=sigma, opt_state=opt_state)
